git: e9a6e6f104 - main - docbuild: update PDF file build scripts to use Git

Glen Barber <[email protected]>
Newsgroups gmane.os.freebsd.devel.cvs.doc
Message-ID <[email protected]>
The branch main has been updated by gjb:

URL: https://cgit.FreeBSD.org/doc/commit/?id=e9a6e6f104b7706ad46bc7b3d88536d3e57902f7

commit e9a6e6f104b7706ad46bc7b3d88536d3e57902f7
Author:     Glen Barber <[email protected]>
AuthorDate: 2020-12-30 16:52:21 +0000
Commit:     Glen Barber <[email protected]>
CommitDate: 2020-12-30 16:52:21 +0000

    docbuild: update PDF file build scripts to use Git
    
    Remove references to CVS/SVN and replace with Git equivalents.
    Note the files are not automatically updated on the builder after
    a change is committed.
    Remove RCSIDs.
    
    Sponsored by:   Rubicon Communications, LLC (netgate.com)
---
 share/tools/dobuild.sh      | 15 +++++++--------
 share/tools/dobuild_wrap.sh | 10 ++++------
 2 files changed, 11 insertions(+), 14 deletions(-)

diff --git a/share/tools/dobuild_wrap.sh b/share/tools/dobuild_wrap.sh
index d0bdf3e246..c62dfa7bfc 100755
--- a/share/tools/dobuild_wrap.sh
+++ b/share/tools/dobuild_wrap.sh
@@ -24,18 +24,17 @@
 # OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 # SUCH DAMAGE.
 #
-# $FreeBSD$
-#
 
+#
 # Wrapper around doc build.  Simplifies main build script.
+# NOTE: This script is not automatically updated on the builder.
 
 #
 # Default configuration.
 #
 DEFAULT_PATH=/bin:/usr/bin:/usr/local/bin
 DEFAULT_BUILDROOT=/local0/docbuild
-DEFAULT_CVSROOT=/home/dcvs
-DEFAULT_DOCSVN="svn://svn.freebsd.org/doc/head"
+DEFAULT_DOCGIT="https://git.freebsd.org/doc.git"
 DEFAULT_BUILDARGS="NO_JPMAN=yes GEN_INDEX=yes"
 DEFAULT_INSTARGS="NO_JPMAN=yes GEN_INDEX=yes INSTALL_ONLY_COMPRESSED=yes"
 # Must keep space between addresses.
@@ -51,8 +50,7 @@ DEFAULT_COMPTYPES="bz2 zip"
 #
 BUILDROOT=${BUILDROOT:-${DEFAULT_BUILDROOT}}; export BUILDROOT
 PATH="${PATH}:${DEFAULT_PATH}"; export PATH
-CVSROOT=${CVSROOT:-${DEFAULT_CVSROOT}}; export CVSROOT
-DOCSVN=${DOCSVN:-${DEFAULT_DOCSVN}}; export DOCSVN
+DOCGIT=${DOCGIT:-${DEFAULT_DOCGIT}}; export DOCGIT
 BUILDDIR=${BUILDDIR:-${BUILDROOT}/build}; export BUILDDIR
 DOCDIR=${DOCDIR:-${BUILDROOT}/build/out}; export DOCDIR
 FORMATS=${FORMATS:-${DEFAULT_FORMATS}}; export FORMATS
_______________________________________________
[email protected] mailing list
https://lists.freebsd.org/mailman/listinfo/dev-commits-doc-all
To unsubscribe, send any mail to "[email protected]"
lmpx.com only provides a reader for public news (NNTP) servers. It is not affiliated with the servers or forums shown here and is not responsible for the content of articles, which is written by their respective authors.
diff --git a/share/tools/dobuild.sh b/share/tools/dobuild.sh
index a2ae5c092d..9e16187121 100755
--- a/share/tools/dobuild.sh
+++ b/share/tools/dobuild.sh
@@ -3,14 +3,13 @@
 # Copyright (c) 2001 Dima Dorfman <[email protected]>
 # Copyright (c) 2004 Simon L. Nielsen <[email protected]>
 #
 # Build the FreeBSD docs from the CVS^WSVN repository.
 #
 #
 # Major variables:
 #
 #	PATH		- The search path as interpreted by the shell.
 #	CVSROOT		- Path to the FreeBSD CVS repository (obsolete)
 #	DOCSVN		- Url to the FreeBSD doc SVN repository.
 #	BUILDDIR	- Where the checked out copies of the files are stored.
 #	DESTDIR		- Where the rendered copies should wind up.
 #	BUILDARGS	- Arguments to pass to make(1) when {build,install}ing.
@@ -29,13 +28,14 @@
 #
 #	0	- success
 #	1	- unknown failure
 #	2	- failure in CVS^SVN operations
 #	3	- failure in make operations
 #
-# $FreeBSD: www/tools/webupdate,v 1.10 2003/11/18 11:00:54 kuriyama Exp $
-#
 
 #
+# NOTE: This script is not automatically updated on the builder.
+#
+
 # WARNING!  This script depend on dobuild_wrap.sh setting the
 # configuration variables in the enviroment.
 #
@@ -61,8 +61,7 @@ if [ -z "${NOCLEAN}" ]; then
 	rm -Rf doc out 2>/dev/null
 
 	echo "===> Check out the new doc"
-	#cvs -qR checkout -P doc || exit 2
-	svn checkout ${DOCSVN} doc || exit 2
+	git clone -b main ${DOCGIT} doc || exit 2
 fi
 
 cd $BUILDDIR/doc || exit 1
@@ -3,14 +3,13 @@
 # Copyright (c) 2004 Simon L. Nielsen <[email protected]>
 #
-# Build the FreeBSD docs from the CVS^WSVN repository.
+# Build the FreeBSD docs from the Git repository.
 #
 #
@@ -3,14 +3,13 @@
 #
 #	PATH		- The search path as interpreted by the shell.
-#	CVSROOT		- Path to the FreeBSD CVS repository (obsolete)
-#	DOCSVN		- Url to the FreeBSD doc SVN repository.
+#	DOCGIT		- Url to the FreeBSD doc Git repository.
 #	BUILDDIR	- Where the checked out copies of the files are stored.
 #	DESTDIR		- Where the rendered copies should wind up.
@@ -29,13 +28,14 @@
 #	0	- success
 #	1	- unknown failure
-#	2	- failure in CVS^SVN operations
+#	2	- failure in Git operations
 #	3	- failure in make operations
 #